import { BrowserModule } from '@angular/platform-browser';
import { Component, Directive, ElementRef, EventEmitter, HostListener, Input, NgModule, Output, Pipe, ViewEncapsulation, forwardRef } from '@angular/core';
import { FormsModule, NG_VALIDATORS, NG_VALUE_ACCESSOR, NgModel } from '@angular/forms';
import { NgbCalendar, NgbDatepickerI18n, NgbModule } from '@ng-bootstrap/ng-bootstrap';
import { DatePipe } from '@angular/common';
import { NgbCalendarPersian } from 'ng2-datepicker-jalali/persian/ngb-calendar-persian';
import { NgbDatepickerI18nPersian } from 'ng2-datepicker-jalali/persian/ngb-datepicker-i18n-persian';
import { NgbDate } from '@ng-bootstrap/ng-bootstrap/datepicker/ngb-date';
import { NgbTime } from '@ng-bootstrap/ng-bootstrap/timepicker/ngb-time';

/**
 * Created by mehrabi-s on 15/04/2017.
 */
var DateTimeJalaliPipe = (function () {
    function DateTimeJalaliPipe() {
    }
    /**
     * @param {?} value
     * @param {...?} args
     * @return {?}
     */
    DateTimeJalaliPipe.prototype.transform = function (value) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        if (value) {
            value = new Date(value);
            if (value) {
                var /** @type {?} */ da = new NgbCalendarPersian().fromGregorian(value);
                return da.year + "/" + da.month + "/" + da.day + " " + value.getHours() + ":" + value.getMinutes();
            }
        }
        return '';
    };
    return DateTimeJalaliPipe;
}());
DateTimeJalaliPipe.decorators = [
    { type: Pipe, args: [{
                name: 'dateTimeJalali'
            },] },
];
/**
 * @nocollapse
 */
DateTimeJalaliPipe.ctorParameters = function () { return []; };

var CUSTOM_INPUT_CONTROL_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(function () { return DatetimepickerComponent; }),
    multi: true
};
var CUSTOM_INPUT_CONTROL_VALIDATOR = {
    provide: NG_VALIDATORS,
    useExisting: forwardRef(function () { return DatetimepickerComponent; }),
    multi: true
};
var DatetimepickerComponent = (function () {
    /**
     * @param {?} elementRef
     */
    function DatetimepickerComponent(elementRef) {
        this.elementRef = elementRef;
        this.OnPersianFormat = new EventEmitter();
        this.disableTime = false;
        this.displayMonths = 1;
        this._dateTimeFormat = '';
        this.onChange = function () {
        };
        this.onTouched = function () {
        };
    }
    /**
     * @return {?}
     */
    DatetimepickerComponent.prototype.ngOnInit = function () {
        this._panelClick = false;
        console.log(this.elementRef.nativeElement.parentElement.dir, this.elementRef.nativeElement.parentElement);
        if (!(this.dir === 'rtl' || this.dir === 'ltr')) {
            var /** @type {?} */ parent_1 = this.elementRef.nativeElement.parentElement;
            while (parent_1 && !(this.dir === 'rtl' || this.dir === 'ltr')) {
                this.dir = parent_1.dir;
                parent_1 = parent_1.parentElement;
            }
            if (!(this.dir === 'rtl' || this.dir === 'ltr')) {
                this.dir = 'rtl';
            }
        }
    };
    /**
     * @param {?} changes
     * @return {?}
     */
    DatetimepickerComponent.prototype.ngOnChanges = function (changes) {
        this.canChange();
    };
    /**
     * @return {?}
     */
    DatetimepickerComponent.prototype.changedTime = function () {
        if (this._time) {
            this.canChange();
        }
    };
    /**
     * @return {?}
     */
    DatetimepickerComponent.prototype.changedDate = function () {
        if (this._date) {
            this.canChange();
        }
    };
    /**
     * @return {?}
     */
    DatetimepickerComponent.prototype.getValue = function () {
        this.applyTextInput();
        if (this._date) {
            var /** @type {?} */ date = new NgbCalendarPersian().toGregorian(this._date);
            if (this.disableTime) {
                this._time = new NgbTime(0, 0, 0);
            }
            if (this._time) {
                date.setHours(this._time.hour);
                date.setMinutes(this._time.minute);
                date.setSeconds(this._time.second);
                this.OnPersianFormat.emit(this._date.year + '/' + this._date.month + '/' + this._date.day +
                    ((this.disableTime) ? '' : ' ' + this._time.hour + ':' + this._time.minute));
                return date;
            }
            else {
                return null;
            }
        }
        else {
            return null;
        }
    };
    /**
     * @return {?}
     */
    DatetimepickerComponent.prototype.applyTextInput = function () {
        if (this._date) {
            if (this.disableTime) {
                this._dateTimeFormat = this.pad(this._date.year, 4) + "/" + this.pad(this._date.month, 2) + "/" + this.pad(this._date.day, 2);
            }
            else if (this._time) {
                this._dateTimeFormat = this.pad(this._date.year, 4) + "/" + this.pad(this._date.month, 2) + "/" + this.pad(this._date.day, 2)
                    + ' ' + (this.pad(this._time.hour, 2) + ":" + this.pad(this._time.minute, 2));
            }
        }
    };
    /**
     * @param {?} str
     * @param {?} max
     * @return {?}
     */
    DatetimepickerComponent.prototype.pad = function (str, max) {
        str = str.toString();
        var /** @type {?} */ i;
        var /** @type {?} */ strR = '';
        for (i = 0; i < max - str.length; i++) {
            strR += '0';
        }
        return strR + str;
    };
    /**
     * @return {?}
     */
    DatetimepickerComponent.prototype.inputBlur = function () {
        if (this._dateTimeFormat) {
            var /** @type {?} */ datetime = this._dateTimeFormat.replace(/\s/gi, ' ').split(' ');
            if ((this.disableTime && datetime.length === 1) || datetime.length === 2) {
                var /** @type {?} */ date = datetime[0].split('/');
                if (date.length === 3 &&
                    +date[0] && +date[0] > 0 && +date[0] < 9999 &&
                    +date[1] && +date[1] > 0 && +date[1] <= 12 &&
                    +date[2] && +date[2] > 0 && +date[2] <= 31) {
                    if (this.disableTime) {
                        this._time = new NgbTime(0, 0, 0);
                        this._date = new NgbDate(+date[0], +date[1], +date[2]);
                    }
                    else if (datetime.length > 1) {
                        var /** @type {?} */ time = datetime[1].split(':');
                        if (time.length === 2 &&
                            +time[0] != null && +time[0] > -1 && +time[0] < 24 &&
                            +time[1] != null && +time[1] > -1 && +time[1] < 60) {
                            this._time = new NgbTime(+time[0], +time[1], 0);
                            this._date = new NgbDate(+date[0], +date[1], +date[2]);
                        }
                        else {
                            this._time = null;
                        }
                    }
                }
                else {
                    this._date = null;
                    this._time = null;
                }
            }
            else {
                this._date = null;
                this._time = null;
            }
        }
        else {
            this._date = null;
            this._time = null;
        }
        this.onChange(this.getValue());
    };
    /**
     * @return {?}
     */
    DatetimepickerComponent.prototype.maxDate = function () {
        if (this.maxDateTime) {
            return new NgbCalendarPersian().fromGregorian(this.maxDateTime);
        }
    };
    /**
     * @return {?}
     */
    DatetimepickerComponent.prototype.minDate = function () {
        if (this.minDateTime) {
            return new NgbCalendarPersian().fromGregorian(this.minDateTime);
        }
    };
    /**
     * @return {?}
     */
    DatetimepickerComponent.prototype.maxTime = function () {
        if (this.maxDateTime) {
            return new NgbTime(this.maxDateTime.getHours(), this.maxDateTime.getMinutes(), this.maxDateTime.getSeconds());
        }
    };
    /**
     * @return {?}
     */
    DatetimepickerComponent.prototype.minTime = function () {
        if (this.minDateTime) {
            return new NgbTime(this.minDateTime.getHours(), this.minDateTime.getMinutes(), this.minDateTime.getSeconds());
        }
    };
    /**
     * @return {?}
     */
    DatetimepickerComponent.prototype.getValidDate = function () {
        if (this._date && (this.minDateTime || this.maxDateTime)) {
            if (this.minDate() &&
                (this.minDate().year > this._date.year ||
                    (this.minDate().year === this._date.year && this.minDate().month > this._date.month) ||
                    (this.minDate().year === this._date.year && this.minDate().month === this._date.month &&
                        this.minDate().day > this._date.day))) {
                return false;
            }
            else if (this.maxDate() &&
                (this.maxDate().year < this._date.year ||
                    (this.maxDate().year === this._date.year && this.maxDate().month < this._date.month) ||
                    (this.maxDate().year === this._date.year && this.maxDate().month === this._date.month &&
                        this.maxDate().day < this._date.day))) {
                return false;
            }
        }
        return true;
    };
    /**
     * @return {?}
     */
    DatetimepickerComponent.prototype.getValidTime = function () {
        if (this.disableTime === true) {
            return true;
        }
        if (this.getValidDate() && this._time && this._date && (this.minDateTime || this.maxDateTime)) {
            if (this.minDateTime &&
                this.minDate() &&
                this.minTime()) {
                if (this.minDate().year === this._date.year &&
                    this.minDate().month === this._date.month &&
                    this.minDate().day === this._date.day) {
                    if (this.minTime().hour > this._time.hour || (this.minTime().hour === this._time.hour &&
                        this.minTime().minute >= this._time.minute)) {
                        return false;
                    }
                }
            }
            if (this.maxDateTime && this.maxDate() && this.maxTime()) {
                if (this.maxDate().year === this._date.year &&
                    this.maxDate().month === this._date.month &&
                    this.maxDate().day === this._date.day) {
                    if (this.maxTime().hour < this._time.hour || (this.maxTime().hour === this._time.hour &&
                        this.maxTime().minute <= this._time.minute)) {
                        return false;
                    }
                }
            }
        }
        return true;
    };
    /**
     * @return {?}
     */
    DatetimepickerComponent.prototype.canChange = function () {
        var /** @type {?} */ value = this.getValue();
        if (this._lastValue !== value) {
            this._lastValue = value;
            this.onChange(value);
        }
    };
    /**
     * @param {?} val
     * @return {?}
     */
    DatetimepickerComponent.prototype.writeValue = function (val) {
        if (val !== this.getValue()) {
            this._value = new Date(val);
            if (this._value && val) {
                this._date = new NgbCalendarPersian().fromGregorian(this._value);
                this._time = new NgbTime(this._value.getHours(), this._value.getMinutes(), 0);
            }
            this.applyTextInput();
        }
    };
    /**
     * @param {?} fn
     * @return {?}
     */
    DatetimepickerComponent.prototype.registerOnChange = function (fn) {
        this.onChange = fn;
    };
    /**
     * @param {?} fn
     * @return {?}
     */
    DatetimepickerComponent.prototype.registerOnTouched = function (fn) {
        this.onTouched = fn;
    };
    /**
     * @return {?}
     */
    DatetimepickerComponent.prototype.validate = function () {
        var /** @type {?} */ err = {
            rangeError: {
                dateTime: this.getValue(),
                max: this.maxDateTime,
                min: this.maxDateTime
            }
        };
        return this._dateTimeFormat || !this.getValidTime() || !this.getValidDate() ? err : null;
    };
    /**
     * @param {?} datePicker
     * @return {?}
     */
    DatetimepickerComponent.prototype.onMouseClick = function (datePicker) {
        if (this.disabled) {
            return;
        }
        if (!this._panelClick) {
            if (this.overlayVisible) {
                this.hide();
            }
            else {
                this.show();
                if (this._date) {
                    datePicker.navigateTo({ year: this._date.year, month: this._date.month });
                }
            }
        }
    };
    /**
     * @return {?}
     */
    DatetimepickerComponent.prototype.show = function () {
        this.overlayVisible = true;
    };
    /**
     * @return {?}
     */
    DatetimepickerComponent.prototype.hide = function () {
        this.overlayVisible = false;
    };
    /**
     * @param {?} event
     * @return {?}
     */
    DatetimepickerComponent.prototype.handleClick = function (event) {
        var /** @type {?} */ clickedComponent = event.target;
        var /** @type {?} */ inside = false;
        do {
            if (clickedComponent === this.elementRef.nativeElement) {
                inside = true;
            }
            clickedComponent = clickedComponent.parentNode;
        } while (clickedComponent);
        if (!inside) {
            if (this.disableTime || (!this.disableTime && !this._panelClick)) {
                this.hide();
            }
        }
        this._panelClick = false;
    };
    return DatetimepickerComponent;
}());
DatetimepickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng2-datetimepicker',
                template: "<div> <div [class.has-danger]=\"!getValidDate()\" class=\"input-group\" dir=\"ltr\"> <a *ngIf=\"dir==='rtl'\" class=\"input-group-addon\" (click)=\"onMouseClick(dp)\"> <svg style=\"width:24px;height:24px\" viewBox=\"0 0 34 28\"> <path fill=\"#000000\" d=\"M31,0H3C1.3,0,0,1.3,0,3v22c0,1.7,1.3,3,3,3h28c1.7,0,3-1.3,3-3    V3C34,1.3,32.7,0,31,0z M32,25c0,0.6-0.4,1-1,1H3c-0.6,0-1-0.4-1-1V8h30V25z M32,6H2V3c0-0.6,0.4-1,1-1h28c0.6,0,1,0.4,1,1V6z     M8,16c1.1,0,2-0.9,2-2s-0.9-2-2-2c-1.1,0-2,0.9-2,2S6.9,16,8,16z M14,16c1.1,0,2-0.9,2-2s-0.9-2-2-2c-1.1,0-2,0.9-2,2    S12.9,16,14,16z M20,16c1.1,0,2-0.9,2-2s-0.9-2-2-2c-1.1,0-2,0.9-2,2S18.9,16,20,16z M26,16c1.1,0,2-0.9,2-2s-0.9-2-2-2    c-1.1,0-2,0.9-2,2S24.9,16,26,16z M8,22c1.1,0,2-0.9,2-2c0-1.1-0.9-2-2-2c-1.1,0-2,0.9-2,2C6,21.1,6.9,22,8,22z M14,22    c1.1,0,2-0.9,2-2c0-1.1-0.9-2-2-2c-1.1,0-2,0.9-2,2C12,21.1,12.9,22,14,22z M20,22c1.1,0,2-0.9,2-2c0-1.1-0.9-2-2-2    c-1.1,0-2,0.9-2,2C18,21.1,18.9,22,20,22z M26,22c1.1,0,2-0.9,2-2c0-1.1-0.9-2-2-2c-1.1,0-2,0.9-2,2C24,21.1,24.9,22,26,22z\" /> </svg> </a> <input #inp class=\"textInput form-control\"  style=\"width: 100%;\" [disabled]=\"disabled\" [placeholder]=\"'yyyy/mm/dd' + (disableTime ? '' : ' HH:MM')\" [mask]=\"'0000/00/00' + (disableTime ? '' :' 00:00')\" [(ngModel)]=\"_dateTimeFormat\" (blur)=\"inputBlur()\" name=\"dp\"> <a *ngIf=\"dir==='ltr'\" class=\"input-group-addon\" (click)=\"onMouseClick()\"> <svg style=\"width:24px;height:24px\" viewBox=\"0 0 34 28\"> <path fill=\"#000000\" d=\"M31,0H3C1.3,0,0,1.3,0,3v22c0,1.7,1.3,3,3,3h28c1.7,0,3-1.3,3-3    V3C34,1.3,32.7,0,31,0z M32,25c0,0.6-0.4,1-1,1H3c-0.6,0-1-0.4-1-1V8h30V25z M32,6H2V3c0-0.6,0.4-1,1-1h28c0.6,0,1,0.4,1,1V6z     M8,16c1.1,0,2-0.9,2-2s-0.9-2-2-2c-1.1,0-2,0.9-2,2S6.9,16,8,16z M14,16c1.1,0,2-0.9,2-2s-0.9-2-2-2c-1.1,0-2,0.9-2,2    S12.9,16,14,16z M20,16c1.1,0,2-0.9,2-2s-0.9-2-2-2c-1.1,0-2,0.9-2,2S18.9,16,20,16z M26,16c1.1,0,2-0.9,2-2s-0.9-2-2-2    c-1.1,0-2,0.9-2,2S24.9,16,26,16z M8,22c1.1,0,2-0.9,2-2c0-1.1-0.9-2-2-2c-1.1,0-2,0.9-2,2C6,21.1,6.9,22,8,22z M14,22    c1.1,0,2-0.9,2-2c0-1.1-0.9-2-2-2c-1.1,0-2,0.9-2,2C12,21.1,12.9,22,14,22z M20,22c1.1,0,2-0.9,2-2c0-1.1-0.9-2-2-2    c-1.1,0-2,0.9-2,2C18,21.1,18.9,22,20,22z M26,22c1.1,0,2-0.9,2-2c0-1.1-0.9-2-2-2c-1.1,0-2,0.9-2,2C24,21.1,24.9,22,26,22z\" /> </svg> </a> </div> <div [style.visibility]=\"!overlayVisible ? 'hidden' : 'visible'\"  class=\"d-inline-block rounded datetime\" [ngClass]=\"{rtl: dir === 'rtl'}\" style=\"padding: 0;\"> <ngb-datepicker #dp (click)=\"_panelClick = true\" [(ngModel)]=\"_date\"  [displayMonths]=\"displayMonths\" (ngModelChange)=\"changedDate()\" [maxDate]=\"maxDate()\" [minDate]=\"minDate()\" [firstDayOfWeek]=\"6\"></ngb-datepicker> <div *ngIf=\"!disableTime\" [class.has-danger]=\"!getValidTime()\" class=\"time d-block d-flex justify-content-center\" style=\"display: flex;\" dir=\"ltr\"> <ngb-timepicker [(ngModel)]=\"_time\" (ngModelChange)=\"changedTime()\" dir=\"ltr\"></ngb-timepicker> </div> </div> </div> ",
                styles: [".time { direction: ltr; align-self: center; } .date { align-self: center; } .time .form-control { width: 100%; } ng2-datetimepicker.form-control { padding: 0; } .datetime { padding: 0; position: absolute; z-index: 1000; display: none; float: left; min-width: 10rem; margin: .125rem 0 0; font-size: 1rem; color: #292b2c; text-align: left; list-style: none; background-color: #fff; background-clip: padding-box; border: 1px solid rgba(0, 0, 0, .15); border-radius: .25rem; } .datetime.rtl .ngb-dp-navigation-chevron::before { transform: rotate(45deg) !important; -webkit-transform: rotate(45deg) !important; -ms-transform: rotate(45deg) !important; margin: 0 0.5rem 0 0 !important; } .datetime.rtl .ngb-dp-navigation-chevron.right:before { -webkit-transform: rotate(225deg) !important; -ms-transform: rotate(225deg) !important; transform: rotate(225deg) !important; margin: 0 0 0 0.5rem !important; } "],
                providers: [
                    { provide: NgbCalendar, useClass: NgbCalendarPersian },
                    { provide: NgbDatepickerI18n, useClass: NgbDatepickerI18nPersian },
                    CUSTOM_INPUT_CONTROL_VALUE_ACCESSOR,
                    CUSTOM_INPUT_CONTROL_VALIDATOR
                ],
                encapsulation: ViewEncapsulation.None
            },] },
];
/**
 * @nocollapse
 */
DatetimepickerComponent.ctorParameters = function () { return [
    { type: ElementRef, },
]; };
DatetimepickerComponent.propDecorators = {
    'OnPersianFormat': [{ type: Output },],
    'disableTime': [{ type: Input, args: ['disableTime',] },],
    'maxDateTime': [{ type: Input },],
    'minDateTime': [{ type: Input },],
    'displayMonths': [{ type: Input },],
    'disabled': [{ type: Input },],
    'overlayVisible': [{ type: Input },],
    'dir': [{ type: Input },],
    'handleClick': [{ type: HostListener, args: ['document:click', ['$event'],] },],
};

/**
 * use https://github.com/M-Ulyanov/ng2-inputmask.
 */
var placeholders = {
    'A': '^[a-zA-ZA-zА-яЁё]',
    '0': '\\d'
};
var InputMaskDirective = (function () {
    /**
     *
    \@param element
    \@param model
     * @param {?} element
     * @param {?} model
     */
    function InputMaskDirective(element, model) {
        this.element = element;
        this.model = model;
        this.state = {
            value: this.getValue()
        };
    }
    /**
     *
     * @return {?}
     */
    InputMaskDirective.prototype.onChange = function () {
        this.applyMask(this.getClearValue(this.getValue()));
    };
    /**
     *
    \@param event
     * @param {?} event
     * @return {?}
     */
    InputMaskDirective.prototype.onKeyPress = function (event) {
        var /** @type {?} */ cursorPosition = this.getCursorPosition();
        var /** @type {?} */ regexp = this.createRegExp(cursorPosition);
        if (regexp != null && !regexp.test(event.key)) {
            event.preventDefault();
        }
    };
    /**
     *
     * @return {?}
     */
    InputMaskDirective.prototype.ngOnInit = function () {
        this.applyMask(this.getClearValue(this.getValue()));
    };
    /**
     *
    \@param value
     * @param {?} value
     * @return {?}
     */
    InputMaskDirective.prototype.applyMask = function (value) {
        var /** @type {?} */ newValue = '';
        var /** @type {?} */ maskPosition = 0;
        if (this.getClearValue(value).length > this.getClearValue(this.mask).length) {
            this.setValue(this.state.value);
            return;
        }
        for (var /** @type {?} */ i = 0; i < value.length; i++) {
            var /** @type {?} */ current = value[i];
            var /** @type {?} */ regexp = this.createRegExp(maskPosition);
            if (regexp != null) {
                if (!regexp.test(current)) {
                    this.setValue(this.state.value);
                    break;
                }
                newValue += current;
            }
            else if (this.mask[maskPosition] === current) {
                newValue += current;
            }
            else {
                newValue += this.mask[maskPosition];
                i--;
            }
            maskPosition++;
        }
        var /** @type {?} */ nextMaskElement = this.mask[maskPosition];
        if (value.length && nextMaskElement != null && /^[-\/\\^$#&@№:<>_\^!*+?.()|\[\]{}]/.test(nextMaskElement)) {
            newValue += nextMaskElement;
        }
        var /** @type {?} */ oldValue = this.state.value;
        var /** @type {?} */ cursorPosition = this.getCursorPosition();
        this.setValue(newValue);
        this.state.value = newValue;
        if (oldValue.length >= cursorPosition) {
            this.setCursorPosition(cursorPosition);
        }
    };
    /**
     *
    \@param position
    \@returns {any}
     * @param {?} position
     * @return {?}
     */
    InputMaskDirective.prototype.createRegExp = function (position) {
        if (this.mask[position] == null) {
            return null;
        }
        var /** @type {?} */ currentSymbol = this.mask[position].toUpperCase();
        var /** @type {?} */ keys = Object.keys(placeholders);
        var /** @type {?} */ searchPosition = keys.indexOf(currentSymbol);
        if (searchPosition >= 0) {
            return new RegExp(placeholders[keys[searchPosition]], 'gi');
        }
        return null;
    };
    /**
     *
    \@returns {any}
     * @return {?}
     */
    InputMaskDirective.prototype.getValue = function () {
        return this.element.nativeElement.value;
    };
    /**
     *
    \@param value
    \@returns {string}
     * @param {?} value
     * @return {?}
     */
    InputMaskDirective.prototype.getClearValue = function (value) {
        return value.trim().replace(/[-\/\\^$#&@№:<>_\^!*+?.()|\[\]{}]/gi, '');
    };
    /**
     *
    \@param value
     * @param {?} value
     * @return {?}
     */
    InputMaskDirective.prototype.setValue = function (value) {
        this.element.nativeElement.value = value;
        this.model.update.emit(value);
    };
    /**
     *
    \@returns {number}
     * @return {?}
     */
    InputMaskDirective.prototype.getCursorPosition = function () {
        return this.element.nativeElement.selectionStart;
    };
    /**
     *
    \@param start
    \@param end
     * @param {?} start
     * @param {?=} end
     * @return {?}
     */
    InputMaskDirective.prototype.setCursorPosition = function (start, end) {
        if (end === void 0) { end = start; }
        this.element.nativeElement.setSelectionRange(start, end);
    };
    return InputMaskDirective;
}());
InputMaskDirective.decorators = [
    { type: Directive, args: [{
                selector: '[mask]'
            },] },
];
/**
 * @nocollapse
 */
InputMaskDirective.ctorParameters = function () { return [
    { type: ElementRef, },
    { type: NgModel, },
]; };
InputMaskDirective.propDecorators = {
    'mask': [{ type: Input },],
    'onChange': [{ type: HostListener, args: ['input',] },],
    'onKeyPress': [{ type: HostListener, args: ['keypress', ['$event'],] },],
};

var DateTimePickerModule = (function () {
    function DateTimePickerModule() {
    }
    return DateTimePickerModule;
}());
DateTimePickerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    DatetimepickerComponent,
                    DateTimeJalaliPipe,
                    InputMaskDirective
                ],
                imports: [
                    BrowserModule,
                    FormsModule,
                    NgbModule.forRoot()
                ],
                exports: [
                    DatetimepickerComponent,
                    DateTimeJalaliPipe
                ],
                providers: [DatePipe]
            },] },
];
/**
 * @nocollapse
 */
DateTimePickerModule.ctorParameters = function () { return []; };

export { DateTimePickerModule, DatetimepickerComponent, DateTimeJalaliPipe };
